@@ -1,10 +1,12 @@
-from ocp_resources.constants import PROTOCOL_ERROR_EXCEPTION_DICT, TIMEOUT_4MINUTES
-from ocp_resources.logger import get_logger
+import logging
+
+from urllib3.exceptions import ProtocolError
+
 from ocp_resources.resource import NamespacedResource
 from ocp_resources.utils import TimeoutExpiredError, TimeoutSampler
 
 
-LOGGER = get_logger(name=__name__)
+LOGGER = logging.getLogger(__name__)
 
 
 class CatalogSourceConfig(NamespacedResource):
@@ -12,27 +14,18 @@ class CatalogSourceConfig(NamespacedResource):
 
     def __init__(
         self,
-        name=None,
-        namespace=None,
-        source=None,
-        target_namespace=None,
-        packages=None,
-        cs_display_name=None,
-        cs_publisher=None,
+        name,
+        namespace,
+        source,
+        target_namespace,
+        packages,
+        cs_display_name,
+        cs_publisher,
         client=None,
         teardown=True,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-        **kwargs,
     ):
         super().__init__(
-            name=name,
-            namespace=namespace,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
-            **kwargs,
+            name=name, namespace=namespace, client=client, teardown=teardown
         )
         self.source = source
         self.target_namespace = target_namespace
@@ -42,9 +35,6 @@ class CatalogSourceConfig(NamespacedResource):
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         res.update(
             {
                 "spec": {
@@ -71,8 +61,8 @@ class CatalogSourceConfig(NamespacedResource):
         samples = TimeoutSampler(
             wait_timeout=timeout,
             sleep=1,
-            exceptions_dict=PROTOCOL_ERROR_EXCEPTION_DICT,
-            func=self.api.get,
+            exceptions=ProtocolError,
+            func=self.api().get,
             field_selector=f"metadata.name=={self.name}",
             namespace=self.namespace,
         )
