@@ -1,4 +1,3 @@
-from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.resource import NamespacedResource
 
 
@@ -7,32 +6,21 @@ class HyperConverged(NamespacedResource):
 
     def __init__(
         self,
-        name=None,
-        namespace=None,
+        name,
+        namespace,
         client=None,
         infra=None,
         workloads=None,
         teardown=True,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-        **kwargs,
     ):
         super().__init__(
-            name=name,
-            namespace=namespace,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
-            **kwargs,
+            name=name, namespace=namespace, client=client, teardown=teardown
         )
         self.infra = infra
         self.workloads = workloads
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
 
         if self.infra:
             res.setdefault("spec", {}).setdefault("infra", {}).update(self.infra)
