@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 
-from ocp_resources.constants import TIMEOUT_4MINUTES
-from ocp_resources.logger import get_logger
+import logging
+
 from ocp_resources.resource import NamespacedResource
 
 
-LOGGER = get_logger(name=__name__)
+LOGGER = logging.getLogger(__name__)
 
 
 class PersistentVolumeClaim(NamespacedResource):
@@ -17,6 +17,7 @@ class PersistentVolumeClaim(NamespacedResource):
 
     class Status(NamespacedResource.Status):
         BOUND = "Bound"
+        TERMINATING = "Terminating"
 
     class AccessMode:
         """
@@ -37,8 +38,8 @@ class PersistentVolumeClaim(NamespacedResource):
 
     def __init__(
         self,
-        name=None,
-        namespace=None,
+        name,
+        namespace,
         client=None,
         storage_class=None,
         accessmodes=None,
@@ -46,16 +47,9 @@ class PersistentVolumeClaim(NamespacedResource):
         size=None,
         hostpath_node=None,
         teardown=True,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
     ):
         super().__init__(
-            name=name,
-            namespace=namespace,
-            client=client,
-            teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
+            name=name, namespace=namespace, client=client, teardown=teardown
         )
         self.accessmodes = accessmodes
         self.volume_mode = volume_mode
@@ -65,9 +59,6 @@ class PersistentVolumeClaim(NamespacedResource):
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         res.update(
             {
                 "spec": {
