@@ -1,4 +1,3 @@
-from ocp_resources.constants import TIMEOUT_4MINUTES
 from ocp_resources.resource import Resource
 
 
@@ -11,24 +10,18 @@ class PriorityClass(Resource):
 
     def __init__(
         self,
-        name=None,
-        client=None,
+        name,
+        client,
         teardown=True,
         value=None,
         global_default=False,
         description=None,
         preemption_policy=None,
-        yaml_file=None,
-        delete_timeout=TIMEOUT_4MINUTES,
-        **kwargs,
     ):
         super().__init__(
             name=name,
             client=client,
             teardown=teardown,
-            yaml_file=yaml_file,
-            delete_timeout=delete_timeout,
-            **kwargs,
         )
         self.value = value
         self.global_default = global_default
@@ -37,9 +30,6 @@ class PriorityClass(Resource):
 
     def to_dict(self):
         res = super().to_dict()
-        if self.yaml_file:
-            return res
-
         if self.value:
             res["value"] = self.value
         if self.global_default:
